@@ -34,6 +34,7 @@ from .runcmd import (
     set_verbose_progress,
     progress,
     error,
+    RuncmdError,
 )
 from .tags import (
     Tags,
@@ -41,13 +42,14 @@ from .tags import (
     TagInUse,
     AlreadyHasDev,
     AlreadyHasFsType,
+    AlreadyHasFsUuid,
+    AlreadyHasLuksUuid,
+    AlreadyHasDeviceMapper,
     AlreadyHasTargetMountPoint,
     AlreadyMounted,
     NeedBothMountPoints,
 )
 from .unmount import unmount, NotMounted
-from .spec import (
-    Spec,
-    expand_templates,
-)
+from .spec import Spec, expand_templates
+from .plugin import Plugin, find_plugins
 from .app import Vmdb2
